-- lua/gemini/init.lua

local api = require("gemini.api")
local M = {}

local function gemini_query(prompt)
	local response = api.get_response(prompt)

	if response then
		-- Display the response in a new buffer
		local new_buf = vim.api.nvim_create_buf(false, true) -- Create a scratch buffer
		vim.api.nvim_buf_set_lines(new_buf, 0, 0, false, vim.split(response, "\n"))
		local new_win = vim.api.nvim_open_win(new_buf, true, {
			relative = "editor",
			width = 80,
			height = 20,
			row = 5,
			col = vim.o.columns / 2 - 40,
			border = "rounded",
			title = "Google AI Response",
		})
	else
		vim.notify("Failed to get a response from Gemini API", vim.log.levels.ERROR)
	end
end

-- Make gemini_query available in M so it can be used by the setup function
M.gemini_query = gemini_query

function M.setup()
	-- Create the user command
	vim.api.nvim_create_user_command("Gemini", function(opts)
		local prompt = opts.args
		if prompt == "" then
			vim.notify("Please provide a prompt for Gemini.", vim.log.levels.WARN)
			return
		end
		M.gemini_query(prompt)  -- Use M.gemini_query instead of gemini_query
	end, {
		desc = "Query Google AI",
		nargs = "+",
		complete = "shellcmd",
	})

	-- Set up keymapping
	vim.keymap.set("n", "<leader>g", function()
		vim.ui.input({ prompt = "Gemini Query: " }, function(input)
			if input then
				M.gemini_query(input)  -- Use M.gemini_query instead of gemini_query
			end
		end)
	end, { desc = "Query Google AI (via Input)" })
end

return M
